local L = LibStub("AceLocale-3.0"):GetLocale("WorldBossStatus")
WorldBossStatus = LibStub("AceAddon-3.0"):NewAddon("WorldBossStatus", "AceConsole-3.0", "AceEvent-3.0" );

local addonName = "WordBossStatus";
local LDB = LibStub("LibDataBroker-1.1", true)
local LDBIcon = LDB and LibStub("LibDBIcon-1.0", true)

worldBosses = { { name = _G.EJ_GetEncounterInfo(691), questId = 32099 },
                { name = _G.EJ_GetEncounterInfo(725), questId = 32098 },
				{ name = _G.EJ_GetEncounterInfo(814), questId = 32518 },	
				{ name = _G.EJ_GetEncounterInfo(826), questId = 32519 }}

statuses = {L["Undefeated"], L["Defeated"] }
statuses[0] = L["Undefeated"]
statuses[1] = L["Defeated"]

colors = {"FF00FF00", "FFFF0000"}
colors[0] = "FF00FF00"
colors[1] = "FFFF0000"


local WorldBossStatusLauncher = LDB:NewDataObject(addonName, {
		type = "launcher",
		icon = "Interface\\TARGETINGFRAME\\UI-RaidTargetingIcon_8.png",
		OnClick = function(clickedframe, button)
			WorldBossStatus:ShowOptions() 
		end,
		OnTooltipShow = function(tt)
			tt:SetText(L["World Boss Status"])				
			tt:AddLine(" ")
			
			for index, boss in ipairs(worldBosses) do
				defeated = IsQuestFlaggedCompleted(boss.questId)
				status = statuses[defeated and 1 or 0]
				
				tt:AddDoubleLine(boss.name..":", status, 1, 1, 1, defeated and 1 or 0, not defeated and 1 or 0, 0)
			end

			tt:AddLine(" ")
			tt:AddLine(L["Click to open the options menu"])
		end,
	})

local defaults = {
	global = {
		MinimapButton = {
			hide = false,
		}, 
		Objectives = {
			hide = true,
		}
	},
};

local options = {
    name = L["World Boss Status"],
    handler = WorldBossStatus,
    type = "group",
    args = {
        showMiniMapButton = {
            type = "toggle",
            name = L["Minimap Button"],
            desc = L["Toggles the display of the minimap button."],
            get = "IsShowMinimapButton",
            set = "ToggleMinimapButton",
        },
    },
}

function WorldBossStatus:IsShowMinimapButton(info)
	return not self.db.global.MinimapButton.hide
end

function WorldBossStatus:ToggleMinimapButton(info, value)
	self.db.global.MinimapButton.hide = not value
end

function WorldBossStatus:IsShowObjectives(info)
	return not self.db.global.Objectives.hide
end

function WorldBossStatus:ToggleObjectives(info, value)
	self.db.global.Objectives = not value	
end

function WorldBossStatus:ShowOptions()
	InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
end

function WorldBossStatus:OnInitialize()	
	self.db = LibStub("AceDB-3.0"):New("WorldBossStatusDB", defaults, true)

	LDBIcon:Register(addonName, WorldBossStatusLauncher, self.db.global.MinimapButton)
	WorldBossStatus:RegisterChatCommand("wbs", "ChatCommandHandler")
	LibStub("AceConfig-3.0"):RegisterOptionsTable(L["World Boss Status"], options)
	self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions(L["World Boss Status"], L["World Boss Status"])
end

function WorldBossStatus:ChatCommandHandler(input)
  if not input or input:trim() == "" then
		WorldBossStatus:ShowStatusInChatWindow()  
    else 
        WorldBossStatus:ShowOptions()
    end
end

function WorldBossStatus:ShowStatusInChatWindow()
	for index, boss in ipairs(worldBosses) do
		local defeated = IsQuestFlaggedCompleted(boss.questId)
		local color = colors[defeated and 1 or 0]
		local status = statuses[defeated and 1 or 0]
				
		self:Print(boss.name..": |c" .. color .. status .."|r")
	end
end

function WorldBossStatus:OnEnable()
	-- Called when the addon is enabled
end

function WorldBossStatus:OnDisable()
    -- Called when the addon is disabled
end
